@@ -3,7 +3,7 @@ package Net::Async::Redis::Protocol;
 use strict;
 use warnings;
 
-our $VERSION = '2.004_001'; # TRIAL VERSION
+our $VERSION = '2.001'; # VERSION
 
 =head1 NAME
 
@@ -149,10 +149,9 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth C<< <TEAM@cpan.org> >> plus contributors as mentioned in
-L<Net::Async::Redis/CONTRIBUTORS>.
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth and others 2015-2020. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth and others 2015-2019. Licensed under the same terms as Perl itself.
 
