@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(IO::Async::Notifier);
 
-our $VERSION = '2.004_001'; # TRIAL VERSION
+our $VERSION = '2.001'; # VERSION
 
 =head1 NAME
 
@@ -35,10 +35,9 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth C<< <TEAM@cpan.org> >> plus contributors as mentioned in
-L<Net::Async::Redis/CONTRIBUTORS>.
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2015-2020. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2015-2017. Licensed under the same terms as Perl itself.
 
