@@ -3,7 +3,7 @@ package Net::Async::Redis::Server::Database;
 use strict;
 use warnings;
 
-our $VERSION = '2.004_001'; # TRIAL VERSION
+our $VERSION = '2.001'; # VERSION
 
 =head1 NAME
 
@@ -12,8 +12,7 @@ Net::Async::Redis::Server::Database - implementation for database-related Redis
 =head1 DESCRIPTION
 
 See L<Net::Async::Redis::Commands> for the full list of commands.
-
-Most of them are not yet implemented.
+Not all of them will be implemented yet.
 
 =cut
 
@@ -145,12 +144,3 @@ sub brpoplpush : method {
 
 1;
 
-=head1 AUTHOR
-
-Tom Molesworth C<< <TEAM@cpan.org> >> plus contributors as mentioned in
-L<Net::Async::Redis/CONTRIBUTORS>.
-
-=head1 LICENSE
-
-Copyright Tom Molesworth 2015-2020. Licensed under the same terms as Perl itself.
-
